@@ -1,6 +1,8 @@
+from __future__ import division, print_function, absolute_import
+
 from .redlichkister import rk, rkb
 from .nrtl import nrtl, nrtlter
 from .wilson import wilson
 from .unifac import unifac
-from .virial import ideal_gas, Tsonopoulos, Abbott
+from .virial import ideal_gas, Tsonopoulos, Abbott, virial
 from .virialgama import virialgama
\ No newline at end of file
