@@ -1,7 +1,7 @@
+from __future__ import division, print_function, absolute_import
 
-# Parámetros y constantes
-kB = 1.38065e-23  # [J/K] Boltzman's constant
-
+# Constants
+kb = 1.3806488e-23 # [J/K] Boltzman's constant
 Na = 6.022142e23  # [mol-1] Avogrado's Number
 
 R = 83.14        #[bar cm3 mol-1 K-1] Ideal gas constant
